==> nextcloud-22.2.8.tgz: nextcloud/apps/serverinfo/l10n/zh_TW.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU 資訊暫時無法使用",
    "Load average: {cpu} (last minute)" : "平均負載：{cpu}（前ㄧ分鐘）",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM：總計 {memTotalBytes}／目前使用量：{memUsageBytes}",
    "RAM info not available" : "沒有可用的 RAM 資訊",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP：總計 {swapTotalBytes}／目前使用量：{swapUsageBytes}",
    "SWAP info not available" : "沒有可用的 SWAP 資訊",
    "Users" : "使用者",
    "Groups" : "群組",
    "Links" : "連結",
    "Emails" : "電子郵件",
    "Federated sent" : "聯盟發送",
    "Federated received" : "聯盟接收",
    "Talk conversations" : "Talk 交談",
    "24 hours" : "24小時",
    "1 hour" : "1小時",
    "5 mins" : "5分鐘",
    "Copy" : "複製",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "請按⌘-C以複製。",
    "Press Ctrl-C to copy." : "請按Ctrl-C以複製。",
    "System" : "系統",
    "Monitoring" : "監控",
    "Monitoring app with useful server information" : "使用有用的伺服器訊息以監控應用程式",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "提供有用的伺服器訊息，例如CPU負載、記憶體使用情況、磁碟使用情況、用戶數等。",
    "Operating System:" : "作業系統：",
    "CPU:" : "CPU：",
    "Unknown Processor" : "未知的處理器",
    "Memory:" : "記憶體：",
    "Server time:" : "伺服器時間：",
    "Uptime:" : "運作時間：",
    "Load" : "負載",
    "Memory" : "記憶體",
    "Disk" : "硬碟",
    "Mount:" : "掛載：",
    "Filesystem:" : "檔案系統：",
    "Size:" : "大小:",
    "Available:" : "可用：",
    "Used:" : "已使用：",
    "You will get a notification once one of your disks is nearly full." : "你將在硬碟使用量快要用完前收到一次通知。",
    "Files:" : "檔案:",
    "Storages:" : "儲存設備：",
    "Free Space:" : "可用空間：",
    "Network" : "網路",
    "Hostname:" : "主機名稱：",
    "DNS:" : "DNS：",
    "Gateway:" : "網路閘道：",
    "Status:" : "狀態：",
    "Speed:" : "速度：",
    "MAC:" : "MAC：",
    "IPv4:" : "IPv4：",
    "IPv6:" : "IPv6：",
    "Active users" : "活動中的使用者",
    "Total users:" : "總使用者：",
    "Shares" : "分享",
    "PHP" : "PHP",
    "Version:" : "版本:",
    "Memory limit:" : "記憶體限制：",
    "Max execution time:" : "最大執行時間：",
    "Upload max size:" : "上傳至多:",
    "Extensions:" : "副檔名：",
    "Unable to list extensions" : "無法列出擴充套件",
    "Database" : "資料庫",
    "Type:" : "類型:",
    "External monitoring tool" : "外部監控工具",
    "You can connect an external monitoring tool by using this end point:" : "您可以使用此終端連接外部監視工具：",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "在URL後面連接參數 \"?format=json\" 將會得到json格式的回傳結果。",
    "To use an access token, please generate one then set it using the following command:" : "要使用存取權杖，請產生一個，然後使用下列指令設定：",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "然後在查詢上面的 URL 時，將權杖與「NC-Token」標頭一起傳遞。",
    "Load average" : "平均負載",
    "Last minute" : "最後一分鐘",
    "Memory info not available" : "記憶體資訊暫時無法使用",
    "Total" : "總計",
    "Current usage" : "目前使用量",
    "Mails" : "郵件",
    "Operating System" : "作業系統",
    "CPU" : "CPU",
    "Server time" : "伺服器時間",
    "Uptime" : "運行時間",
    "Mount" : "掛載",
    "Filesystem" : "檔案系統",
    "Size" : "大小",
    "Available" : "可用",
    "Used" : "已使用",
    "Hostname" : "主機名稱",
    "DNS" : "DNS",
    "Gateway" : "預設網路閘道",
    "Status" : "狀態",
    "Speed" : "速度",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Memory Limit:" : "記憶體限制:",
    "Max Execution Time:" : "最大執行時間:",
    "To use an access token please generate one then set it using the following command:" : "要使用存取權杖，請先生成一個，然後使用以下指令來設定：",
    "Files" : "檔案",
    "Storages" : "儲存空間",
    "Free Space" : "可用空間",
    "Total users" : "總使用者",
    "Version" : "版本",
    "Memory limit" : "記憶體限制",
    "Max execution time" : "最長執行時間",
    "Upload max size" : "最大上傳大小",
    "Type" : "類型",
    "You can connect an external monitoring tool by using this end point" : "您可以使用此端點來連線至外部監視工具",
    "To use an access token, please generate one then set it using the following command" : "要使用存取權杖，請先生成一個，然後使用以下指令來設定"
},
"nplurals=1; plural=0;");

==> nextcloud-23.0.9.tgz: nextcloud/apps/serverinfo/l10n/zh_TW.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU 資訊暫時無法使用",
    "Load average: {cpu} (last minute)" : "平均負載：{cpu}（前ㄧ分鐘）",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM：總計 {memTotalBytes}／目前使用量：{memUsageBytes}",
    "RAM info not available" : "沒有可用的 RAM 資訊",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP：總計 {swapTotalBytes}／目前使用量：{swapUsageBytes}",
    "SWAP info not available" : "沒有可用的 SWAP 資訊",
    "Users" : "使用者",
    "Groups" : "群組",
    "Links" : "連結",
    "Emails" : "電子郵件",
    "Federated sent" : "聯盟發送",
    "Federated received" : "聯盟接收",
    "Talk conversations" : "Talk 交談",
    "24 hours" : "24小時",
    "1 hour" : "1小時",
    "5 mins" : "5分鐘",
    "Copy" : "複製",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "請按⌘-C以複製。",
    "Press Ctrl-C to copy." : "請按Ctrl-C以複製。",
    "System" : "系統",
    "Monitoring" : "監控",
    "Monitoring app with useful server information" : "使用有用的伺服器訊息以監控應用程式",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "提供有用的伺服器訊息，例如CPU負載、記憶體使用情況、磁碟使用情況、用戶數等。",
    "Operating System:" : "作業系統：",
    "CPU:" : "CPU：",
    "Unknown Processor" : "未知的處理器",
    "Memory:" : "記憶體：",
    "Server time:" : "伺服器時間：",
    "Uptime:" : "運作時間：",
    "Temperature" : "氣溫",
    "Load" : "負載",
    "Memory" : "記憶體",
    "Disk" : "硬碟",
    "Mount:" : "掛載：",
    "Filesystem:" : "檔案系統：",
    "Size:" : "大小:",
    "Available:" : "可用：",
    "Used:" : "已使用：",
    "You will get a notification once one of your disks is nearly full." : "你將在硬碟使用量快要用完前收到一次通知。",
    "Files:" : "檔案:",
    "Storages:" : "儲存設備：",
    "Free Space:" : "可用空間：",
    "Network" : "網路",
    "Hostname:" : "主機名稱：",
    "DNS:" : "DNS：",
    "Gateway:" : "網路閘道：",
    "Status:" : "狀態：",
    "Speed:" : "速度：",
    "MAC:" : "MAC：",
    "IPv4:" : "IPv4：",
    "IPv6:" : "IPv6：",
    "Active users" : "活動中的使用者",
    "Total users:" : "總使用者：",
    "Shares" : "分享",
    "PHP" : "PHP",
    "Version:" : "版本:",
    "Memory limit:" : "記憶體限制：",
    "Max execution time:" : "最大執行時間：",
    "Upload max size:" : "上傳至多:",
    "Extensions:" : "擴充套件：",
    "Unable to list extensions" : "無法列出擴充套件",
    "Database" : "資料庫",
    "Type:" : "類型:",
    "External monitoring tool" : "外部監控工具",
    "You can connect an external monitoring tool by using this end point:" : "您可以使用此端點連結外部監視工具：",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "在 URL 結尾接上 \"?format=json\" 即可取得 JSON 格式的回傳結果。",
    "To use an access token, please generate one then set it using the following command:" : "要使用存取權杖，請產生一個，然後使用下列指令設定：",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "然後在查詢上面的 URL 時，將權杖與「NC-Token」標頭一起傳遞。",
    "Load average" : "平均負載",
    "Last minute" : "最後一分鐘",
    "Memory info not available" : "記憶體資訊暫時無法使用",
    "Total" : "總計",
    "Current usage" : "目前使用量",
    "Mails" : "郵件",
    "Operating System" : "作業系統",
    "CPU" : "CPU",
    "Server time" : "伺服器時間",
    "Uptime" : "運行時間",
    "Mount" : "掛載",
    "Filesystem" : "檔案系統",
    "Size" : "大小",
    "Available" : "可用",
    "Used" : "已使用",
    "Hostname" : "主機名稱",
    "DNS" : "DNS",
    "Gateway" : "預設網路閘道",
    "Status" : "狀態",
    "Speed" : "速度",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Memory Limit:" : "記憶體限制:",
    "Max Execution Time:" : "最大執行時間:",
    "To use an access token please generate one then set it using the following command:" : "要使用存取權杖，請先生成一個，然後使用以下指令來設定：",
    "Files" : "檔案",
    "Storages" : "儲存空間",
    "Free Space" : "可用空間",
    "Total users" : "總使用者",
    "Version" : "版本",
    "Memory limit" : "記憶體限制",
    "Max execution time" : "最長執行時間",
    "Upload max size" : "最大上傳大小",
    "Type" : "類型",
    "You can connect an external monitoring tool by using this end point" : "您可以使用此端點來連線至外部監視工具",
    "To use an access token, please generate one then set it using the following command" : "要使用存取權杖，請先生成一個，然後使用以下指令來設定"
},
"nplurals=1; plural=0;");
